{**************************************************************
DSOA MK3 Display Routines
for use with Rev 2.0 hardware
Started       : 14/12/96
Last Edited   : 13/5/98
(C)1996 David L. Jones & David Bulfoni TRONNORT Technology
***************************************************************}
unit DSOA3_D3;

interface
{**************************************************************}
uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, ExtCtrls, StdCtrls, Spin, Menus, DSOA3_I2;
const
  tval : array [1..6] of word = (100,40,20,10,4,2);
  vval : array [0..6] of double = (0,2,1,0.5,0.2,0.1,0.05);
  TimeVals : Array [0..7] of double = (50,100,500,1e3,5e3,10e3,
                                       50e3,500e3);{base is Nano }
  tbaseval : array [0..17,1..2] of byte = ((7,100),(7,40),(7,20),(6,100),
                                           (6,40),(5,100),(4,100),(4,40),
                                           (3,100),(2,100),(2,40),(1,100),
                                           (0,100),(0,40),(0,20),(0,10),
                                           (0,4),(0,1));
{50ms ,20ms ,10ms ,5ms ,2ms ,1ms ,500us ,200us ,100us ,50us ,20us ,10us ,5us,
2us ,1us ,500ns ,200ns ,100ns}

procedure Draw_border (xx1,yy1,xx2,yy2:word; ss:Tcanvas);
procedure Draw_Grid   (xx1,yy1,xx2,yy2:word; ss:Tcanvas);
function  Simul_data  (n,c,x,test : word) : byte;
procedure Draw_Pointer (xx,yy:word; ss:Tcanvas);
function CalculateTime (t,timebaseVal,NumSamples:integer; xoff : tscrollbar):String;
function CalculateVolt (v,ch,chvalue:word):String;
function CalculateDivisionTime (clockset,divisonset:integer):double;
function CalculateTimeValue (t,timebaseVal,NumSamples:integer;xoff : tscrollbar):double;
function DisplayEngTime (temp : double):string;

implementation

{***********************************************}
procedure Draw_screw  (xx1,yy1,xx2,yy2:word; ss:TCanvas);
begin
  with ss do begin
    moveto (xx1+1,yy1-1); lineto (xx2-1,yy1-1); lineto (xx2+1,yy1+1);
    lineto (xx2+1,yy2-1); lineto (xx2-1,yy2+1); lineto (xx1+1,yy2+1);
    lineto (xx1-1,yy2-1); lineto (xx1-1,yy1+1); lineto (xx1+1,yy1-1);
    moveto (xx1  ,yy1);   lineto (xx2  ,yy2);
  end;
end;

{***********************************************}
procedure Draw_box (xx1,yy1,xx2,yy2:word; ss:TCanvas);
begin
  with ss do begin
    moveto (xx1,yy1); lineto (xx1,yy2); lineto (xx2,yy2);
    lineto (xx2,yy1); lineto (xx1,yy1);
  end;
end;

{***********************************************}
procedure Draw_side (xx1,yy1,xx2,yy2,doff:word; ss:TCanvas);
begin
  with ss do begin
    draw_box (xx1,yy1,xx2,yy2,ss);
    draw_box (xx1+doff,yy1+doff,xx2-doff,yy2-doff,ss);
    moveto (xx1,yy1); lineto (xx1+doff,yy1+doff);
    moveto (xx1,yy2); lineto (xx1+doff,yy2-doff);
    moveto (xx2,yy2); lineto (xx2-doff,yy2-doff);
    moveto (xx2,yy1); lineto (xx2-doff,yy1+doff);
  end;
end;

{***********************************************}
procedure Draw_Border (xx1,yy1,xx2,yy2:word; ss:TCanvas);
var xx,yy,c,x1,x2,y1,y2 : word;
begin
  with ss do begin
    pen.color := clsilver;
    for c:= 5 to 12 do begin
      moveto (xx1+c,yy1+c); lineto (xx1+c,yy2-c); lineto (xx2-c,yy2-c);
      lineto (xx2-c,yy1+c); lineto (xx1+c,yy1+c);
    end;
    pen.color := clgray;
    for c:= 14 to 16 do begin
      moveto (xx1+c,yy2-c); lineto (xx1+c,yy1+c); lineto (xx2-c,yy1+c);end;
    for c:= 1 to 3 do begin
      moveto (xx1+c,yy2-c); lineto (xx2-c,yy2-c); lineto (xx2-c,yy1+c);end;
    pen.color := clblack;
    draw_side (xx1,yy1,xx2,yy2,4,ss);
    draw_side (xx1+13,yy1+13,xx2-13,yy2-13,4,ss);
    pen.color := clsilver;
    for c:= 5 to 12 do draw_box (xx1+c,yy1+c,xx2-c,yy2-c,ss);
    x1 := 7; y1 := x1; x2 := 12; y2 := x2;
    pen.color := clwhite;
    for c := x1 to x2 do begin
      moveto (xx1+x1,yy1+c); lineto (xx1+x2,yy1+c);
      moveto (xx2-x1,yy1+c); lineto (xx2-x2,yy1+c);
      moveto (xx2-x1,yy2-c); lineto (xx2-x2,yy2-c);
      moveto (xx1+x1,yy2-c); lineto (xx1+x2,yy2-c);
    end;
    pen.color := clblack;
    draw_screw (xx1+x1,yy1+y1,xx1+x2,yy1+y2,ss);
    draw_screw (xx2-x2,yy1+y1,xx2-x1,yy1+y2,ss);
    draw_screw (xx1+x1,yy2-y2,xx1+x2,yy2-y1,ss);
    draw_screw (xx2-x2,yy2-y2,xx2-x1,yy2-y1,ss);
  end;
end;

{***********************************************}
procedure Draw_Grid   (xx1,yy1,xx2,yy2:word; ss:Tcanvas);
var x,y,c : word;
begin
  with ss do begin
    Pen.Color:=clGray;
    x:=0; y:=0;
    for c:=0 to 10 do begin MoveTo(xx1+x,yy1); LineTo(xx1+x,yy2); inc(x,50); end;
    for c:=0 to 8  do begin MoveTo(xx1,yy1+y); LineTo(xx2,yy1+y); inc(y,32); end;
  end;
end;

{***********************************************}
procedure Draw_Pointer (xx,yy:word; ss:Tcanvas);
begin
  with ss do begin
    pen.color := clblue;
    moveto (xx,yy-5); lineto (xx,yy+5);
    moveto (xx-5,yy); lineto (xx+5,yy);
    moveto (xx-2,yy-2); lineto (xx-2,yy+2);
    lineto (xx+2,yy+2); lineto (xx+2,yy-2);
    lineto (xx-2,yy-2);
  end;
end;
{*********************************************************}
function CalculateDivisionTime (clockset,divisonset:integer):double;
var
  clockspeed,timepersample : double;
begin
  clockspeed := 20.0e+6;
  case clockset of
  0: timepersample := ((1/(clockspeed/1000))*divisonset);
  1: timepersample := ((1/(clockspeed/2))*divisonset);
  2: timepersample := ((1/(clockspeed/20))*divisonset);
  3: timepersample := ((1/(clockspeed/200))*divisonset);
  4: timepersample := ((1/(clockspeed))*divisonset);
  5: timepersample := ((1/(clockspeed/10))*divisonset);
  6: timepersample := ((1/(clockspeed/100))*divisonset);
  7: timepersample := ((1/(clockspeed/10000))*divisonset);
  end;
end;

{*********************************************************}
function DisplayEngTime (temp : double):string;
var ts : string;
begin
  if abs(temp) = 0 then          DisplayEngTime := '0.00 s';
  if (abs(temp) > 0) and (abs(temp) < 1000) then
    begin str(temp:4:2,ts);      DisplayEngTime := ts+' ns'; end;
  if (abs(temp) >= 1e3) and (abs(temp) < 1e6) then
    begin str(temp/1000:4:2,ts); DisplayEngTime := ts+' us'; end;
  if (abs(temp) >= 1e6) and (abs(temp) < 1e9) then
    begin str(temp/1e6:4:2,ts);  DisplayEngTime := ts+' ms'; end;
  if (abs(temp) >= 1e9) then {and (abs(temp) < 1e12) then}
    begin str(temp/1e9:4:2,ts);  DisplayEngTime := ts+' s'; end;
end;

{*********************************************************}
function CalculateTimeValue (t,timebaseVal,NumSamples:integer;xoff : tscrollbar):double;
var temp : double;
begin
  case NumSamples of
  100: temp := t/50;
   40: temp := (xoff.position-  5) + (t/50);
   20: temp := (xoff.position- 20) + (t/50);
   10: temp := (xoff.position- 45) + (t/50);
    4: temp := (xoff.position-120) + (t/50);
    2: temp := (xoff.position-245) + (t/50);
  end;
  CalculateTimeValue := temp*NumSamples*TimeVals[TbaseVal[TimeBaseVal,1]];
end;

{*********************************************************}
function CalculateTime (t,timebaseVal,NumSamples:integer;xoff : tscrollbar):String;
begin
  CalculateTime := DisplayEngTime(CalculateTimeValue(t,timebaseVal,NumSamples,xoff));
end;

{*********************************************************}
function CalculateTimeDiff (t1,t2,tb1,tb2,Ns1,Ns2:integer;xp1,xp2: tscrollbar):String;
begin
  CalculateTimeDiff := DisplayEngTime(CalculateTimeValue(t1,tb1,Ns1,xp1)-
                                      CalculateTimeValue(t2,tb2,Ns2,xp2));
end;

{***************************************************************}
function CalculateVolt (v,ch,chValue:word):String;
var temp1,temp2 : double;
    ts1,ts2 : string;
begin
  temp1 := (v*8)/256;
  temp2 := temp1*vval[ChValue];
  str (temp2:3:2,ts1);
  case ch of
  1: CalculateVolt := 'V1(t) = '+ts1+' Volts';
  2: CalculateVolt := 'V2(t) = '+ts1+' Volts';
  end;
end;

{***********************************************}
function  Simul_data  (n,c,x,Test : word) : byte;
begin
  Case Test of
  1 : begin
        case n of
        1: Simul_data := round((127/(x*2)) * sin(c*6.282/(1024/(3*x))))+127;
        2: Simul_data := round((127/(x*2)) * cos(c*6.282/(1024/(3*x))))+127;
        end;
      end;
  2 : begin
        case n of
        1: begin
             case c of
             1..23    : Simul_data := 0;
             24..223  : Simul_data := c-24;
             224..423 : Simul_data := 200;
             424..623 : Simul_data := 623-c;
             624..823 : Simul_data := 127;
             end;
           end;
        2: begin
             case c of
             1..23    : Simul_data := 0;
             24..223  : Simul_data := c-24;
             224..423 : Simul_data := 200;
             424..623 : Simul_data := 623-c;
             624..823 : Simul_data := 127;
             end;
           end;
        end;
      end;
  3 : begin;
      end;
  4 : begin
      end;
  else begin
    case n of
    1: begin
         case c of
          1..23   : Simul_data := 0;
          24..50  : Simul_data := 127-(c-24);
          51..60  : Simul_data := 255;
          61..70  : Simul_data := 0;
          71..80  : Simul_data := 255;
          81..90  : Simul_data := 0;
          91..100 : Simul_data := 255;
         101..110 : Simul_data := 0;
         111..120 : Simul_data := 255;
         121..130 : Simul_data := 0;
         131..230 : Simul_data := trunc(128 * sin(c*6.282/100))+127;
         231..330 : Simul_data := trunc(128 * cos(c*6.282/100))+127;
         331..400 : Simul_data := 127;
         401..523 : Simul_data := trunc((50 * sin(c*6.282/50))+55);
         else Simul_data := trunc(128 * sin(c*6.282/128+(x*3.141/3600)))+127;
         end;
       end;
    2: begin
         case c of
          1..23   : Simul_data := 0;
          24..50  : Simul_data := 127+(c-24);
          51..60  : Simul_data := 0;
          61..70  : Simul_data := 255;
          71..80  : Simul_data := 0;
          81..90  : Simul_data := 255;
          91..100 : Simul_data := 0;
         101..110 : Simul_data := 255;
         111..120 : Simul_data := 0;
         121..130 : Simul_data := 255;
         131..230 : Simul_data := trunc(128 * cos(c*6.282/100))+127;
         231..330 : Simul_data := trunc(128 * sin(c*6.282/100))+127;
         331..400 : Simul_data := 127;
         401..523 : Simul_data := trunc((50 * cos(c*6.282/50))+55);
         else Simul_data := trunc(128 * cos(c*6.282/128+(x*3.141/180)))+127;
         end;
       end;
    end;
  end;
end;
end;
end.
